import React, { FC, useCallback, useEffect, useState } from 'react';
import { View, Text, Image, TouchableOpacity, Linking, Dimensions, FlatList } from 'react-native';
import ImageView from 'better-react-native-image-viewing';
import { styles } from './styles';
import { CommonActions, useFocusEffect, useNavigation } from '@react-navigation/native';
import { Colors } from 'src/theme';
import { styles as ButtonStyles } from 'src/components/RegionPopup/style';

import { ScrollView } from 'react-native-gesture-handler';
import { NAVIGATION_PAGES } from 'src/types';
import { API_HOST } from 'src/constants';
import { StoreType, storage } from 'src/storage';
import { ButtonVariants } from 'src/types/components';
import formatNumber from '../../TravelsScreen/utils/formatNumber';
import { MaterialCommunityIcons } from '@expo/vector-icons';

import ChevronLeft from 'assets/icons/chevron-left.svg';
import MapSvg from 'assets/icons/travels-screens/map-location.svg';
import AddImgSvg from 'assets/icons/travels-screens/add-img.svg';
import ShareIcon from 'assets/icons/share.svg';
import GigtIcon from 'assets/icons/events/gift.svg';
import CalendarCheckIcon from 'assets/icons/events/calendar-check.svg';
import CalendarIcon from 'assets/icons/events/calendar-solid.svg';
import EarthIcon from 'assets/icons/travels-section/earth.svg';
import NomadsIcon from 'assets/icons/bottom-navigation/travellers.svg';
import LocationIcon from 'assets/icons/bottom-navigation/map.svg';
import FileIcon from 'assets/icons/events/file-solid.svg';
import ImageIcon from 'assets/icons/events/image.svg';
import { getFontSize } from 'src/utils';

const testData = [
  {
    id: 1,
    title: 'Attachment 1',
    url: ''
  },
  {
    id: 2,
    title: 'Attachment 2 dgfgs sgfbfsg tsrgrsz sgb',
    url: ''
  },
  {
    id: 3,
    title: 'Attachment 3',
    url: ''
  },
  {
    id: 4,
    title: 'Attachment 4',
    url: ''
  },
  {
    id: 5,
    title: 'Attachment 5',
    url: ''
  },
  {
    id: 6,
    title: 'Attachment 6',
    url: ''
  },
  {
    id: 7,
    title: 'Attachment 7',
    url: ''
  },
  {
    id: 8,
    title: 'Attachment 8',
    url: ''
  },
  {
    id: 9,
    title: 'Attachment 9',
    url: ''
  }
];

const fileWidth = Dimensions.get('window').width / 5;

const EventScreen = () => {
  const token = (storage.get('token', StoreType.STRING) as string) ?? null;
  const navigation = useNavigation();
  const [isLoading, setIsLoading] = useState(true);
  const [isExpanded, setIsExpanded] = useState(false);

  const renderItem = ({ item, index }) => {
    const totalItems = testData.length;
    if (!isExpanded && index === 7 && totalItems > 8) {
      return (
        <TouchableOpacity
          style={{
            width: fileWidth,
            alignItems: 'center',
            gap: 4
          }}
          onPress={() => setIsExpanded(true)}
        >
          <View
            style={{
              backgroundColor: Colors.FILL_LIGHT,
              borderRadius: 8,
              alignItems: 'center',
              justifyContent: 'center',
              height: fileWidth,
              width: fileWidth
            }}
          >
            <MaterialCommunityIcons name="dots-horizontal" size={36} color={Colors.DARK_BLUE} />
          </View>
        </TouchableOpacity>
      );
    }

    return (
      <TouchableOpacity
        style={{
          width: fileWidth,
          alignItems: 'center',
          gap: 4
        }}
        onPress={() => {
          // Linking.openURL(item.url);
        }}
      >
        <View
          style={{
            backgroundColor: Colors.FILL_LIGHT,
            borderRadius: 8,
            alignItems: 'center',
            justifyContent: 'center',
            height: fileWidth,
            width: fileWidth
          }}
        >
          <MaterialCommunityIcons name="file" size={36} color={Colors.DARK_BLUE} />
        </View>
        <Text
          style={{ fontSize: 12, fontWeight: '600', color: Colors.DARK_BLUE }}
          numberOfLines={2}
        >
          {item.title}
        </Text>
      </TouchableOpacity>
    );
  };

  return (
    <View style={styles.container}>
      <TouchableOpacity
        onPress={() => {
          navigation.goBack();
        }}
        style={styles.backButton}
      >
        <View style={styles.chevronWrapper}>
          <ChevronLeft fill={Colors.WHITE} />
        </View>
      </TouchableOpacity>

      <ScrollView
        contentContainerStyle={{}}
        nestedScrollEnabled={true}
        showsVerticalScrollIndicator={false}
      >
        <View style={styles.emptyImage}>
          <Image
            source={require('../../../../../assets/images/logo-opacity.png')}
            style={{ width: 100, height: 100 }}
          />
          <Text style={styles.emptyImageText}>No image available at this location</Text>
        </View>

        <TouchableOpacity
          onPress={() => {
            // route.params?.isTravelsScreen || route.params?.isProfileScreen
            //   ? navigation.dispatch(
            //       CommonActions.reset({
            //         index: 1,
            //         routes: [
            //           {
            //             name: NAVIGATION_PAGES.IN_APP_MAP_TAB,
            //             state: {
            //               routes: [
            //                 {
            //                   name: NAVIGATION_PAGES.MAP_TAB,
            //                   params: { id: regionId, type: type === 'nm' ? 'regions' : 'places' }
            //                 }
            //               ]
            //             }
            //           }
            //         ]
            //       })
            //     )
            //   : navigation.goBack();
          }}
          style={styles.goToMapBtn}
        >
          <View style={styles.chevronWrapper}>
            <MapSvg fill={Colors.WHITE} />
          </View>
        </TouchableOpacity>

        <View
          style={{
            position: 'absolute',
            width: 71,
            height: 31,
            top: 170,
            left: 0,
            justifyContent: 'center',
            alignItems: 'center',
            zIndex: 2,
            backgroundColor: Colors.ORANGE,
            borderTopRightRadius: 4,
            borderBottomRightRadius: 4,
            paddingRight: 10,
            paddingLeft: 16
          }}
        >
          <Text
            style={{
              textTransform: 'uppercase',
              fontSize: getFontSize(16),
              fontWeight: '700',
              color: Colors.WHITE
            }}
          >
            Tour
          </Text>
        </View>

        <View style={styles.wrapper}>
          <View style={styles.nameContainer}>
            <Text style={styles.title}>Meeting in San Clemente</Text>
            <TouchableOpacity
              onPress={() => {}}
              style={{
                alignItems: 'center',
                justifyContent: 'center',
                paddingLeft: 8
              }}
            >
              <ShareIcon
                width={20}
                height={20}
                fill={Colors.DARK_BLUE}
                style={{ alignSelf: 'center' }}
              />
            </TouchableOpacity>
          </View>

          <TouchableOpacity
            style={{
              flexDirection: 'row',
              alignItems: 'center',
              justifyContent: 'center',
              paddingVertical: 8,
              paddingHorizontal: 12,
              borderRadius: 20,
              backgroundColor: Colors.ORANGE,
              gap: 6
            }}
          >
            {true ? (
              <CalendarCheckIcon fill={Colors.WHITE} width={16} height={16} />
            ) : (
              <GigtIcon fill={Colors.WHITE} width={16} height={16} />
            )}
            <Text
              style={{
                color: Colors.WHITE,
                fontSize: getFontSize(14),
                fontFamily: 'montserrat-700',
                textTransform: 'uppercase'
              }}
            >
              Join - 2000$
            </Text>
          </TouchableOpacity>

          <View style={styles.divider} />

          <View style={{ flexDirection: 'row', alignItems: 'center', gap: 4 }}>
            <View style={{ flexDirection: 'row', alignItems: 'center', gap: 4, flex: 1 }}>
              <CalendarIcon fill={Colors.DARK_BLUE} height={20} width={20} />
              <Text
                style={{
                  fontSize: getFontSize(12),
                  fontWeight: '600',
                  color: Colors.DARK_BLUE,
                  flex: 1
                }}
              >
                13 January, 2025
              </Text>
            </View>

            <View style={{ flexDirection: 'row', alignItems: 'center', gap: 4, flex: 1 }}>
              <EarthIcon fill={Colors.DARK_BLUE} height={20} width={20} />
              <Text
                style={{
                  fontSize: getFontSize(12),
                  fontWeight: '600',
                  color: Colors.DARK_BLUE,
                  flex: 1
                }}
              >
                San Clemente, USA
              </Text>
            </View>
          </View>

          <View style={{ flexDirection: 'row', alignItems: 'center', gap: 4 }}>
            <View style={{ flexDirection: 'row', alignItems: 'center', gap: 4, flex: 1 }}>
              <LocationIcon fill={Colors.DARK_BLUE} height={20} width={20} />
              <Text
                style={{
                  fontSize: getFontSize(12),
                  fontWeight: '600',
                  color: Colors.DARK_BLUE,
                  flex: 1
                }}
              >
                301 N El Camino Real
              </Text>
            </View>

            <View style={{ flexDirection: 'row', alignItems: 'center', gap: 4, flex: 1 }}>
              <NomadsIcon fill={Colors.DARK_BLUE} height={20} width={20} />
              <Text
                style={{
                  fontSize: getFontSize(12),
                  fontWeight: '600',
                  color: Colors.DARK_BLUE,
                  flex: 1
                }}
              >
                <Text style={{ fontWeight: '700' }}>164/300</Text> Spots Available
              </Text>
            </View>
          </View>

          <View style={styles.stats}>
            {true ? (
              <View style={{ gap: 8, flex: 1 }}>
                <Text style={[styles.travelSeriesTitle, { fontSize: 12 }]}>Host</Text>
                <TouchableOpacity
                  style={[styles.statItem, { justifyContent: 'flex-start' }]}
                  onPress={() =>
                    navigation.navigate(
                      ...([
                        NAVIGATION_PAGES.USERS_LIST,
                        {
                          id: 720,
                          isFromHere: true,
                          type: 'nm'
                        }
                      ] as never)
                    )
                  }
                >
                  <View style={styles.userImageContainer}>
                    <Image
                      source={{ uri: API_HOST }}
                      style={[styles.userImage, { marginLeft: 0 }]}
                    />
                    <View style={{ justifyContent: 'space-between' }}>
                      <Text
                        style={{
                          fontFamily: 'montserrat-700',
                          fontSize: 12,
                          color: Colors.DARK_BLUE
                        }}
                      >
                        Harry Mitsidis
                      </Text>
                      <Text style={{ fontWeight: '600', fontSize: 12, color: Colors.DARK_BLUE }}>
                        NM: <Text style={{ fontFamily: 'montserrat-700' }}>1284</Text> / UN:{' '}
                        <Text style={{ fontFamily: 'montserrat-700' }}>193</Text>
                      </Text>
                    </View>
                  </View>
                </TouchableOpacity>
              </View>
            ) : (
              <View style={[styles.statItem, { justifyContent: 'flex-start' }]} />
            )}

            {true ? (
              <View style={{ gap: 8, flex: 1 }}>
                <Text style={[styles.travelSeriesTitle, { fontSize: 12 }]}>Participants</Text>

                <TouchableOpacity
                  style={[styles.statItem, { justifyContent: 'flex-end' }]}
                  onPress={() =>
                    navigation.navigate(
                      ...([
                        NAVIGATION_PAGES.USERS_LIST,
                        {
                          id: 720,
                          isFromHere: false,
                          type: 'nm'
                        }
                      ] as never)
                    )
                  }
                >
                  <View style={styles.userImageContainer}>
                    {/* {data?.data.users_who_visited_region &&
                    data?.data.users_who_visited_region.length > 0 &&
                    data?.data.users_who_visited_region?.map((user, index) => (
                      <Image
                        key={index}
                        source={{ uri: API_HOST + user }}
                        style={[styles.userImage]}
                      />
                    ))} */}
                    <View style={styles.userCountContainer}>
                      <Text style={styles.userCount}>
                        {/* {formatNumber(data?.data.users_who_visited_region_count ?? 0)} */}
                      </Text>
                    </View>
                  </View>
                </TouchableOpacity>
              </View>
            ) : (
              <View style={[styles.statItem, { justifyContent: 'flex-end' }]} />
            )}
          </View>

          <View style={[styles.divider]} />

          <View style={{ gap: 16 }}>
            <Text style={styles.travelSeriesTitle}>Details</Text>
            <Text style={{ fontWeight: '600', fontSize: 13, color: Colors.DARK_BLUE }}>
              Lorem Ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum
              has been the industry's standard dummy text ever since the 1500s, when an unknown
              printer took a galley of type and scrambled it to make a type specimen book. It has
              survived not only five centuries, but also the leap into electronic typesetting,
              remaining essentially unchanged. It was popularised in the 1960s with the release of
              Letraset sheets containing Lorem Ipsum passages, and more recently with desktop
              publishing software like Aldus PageMaker including versions of Lorem Ipsum.
            </Text>
          </View>

          <View style={{ gap: 16 }}>
            <View
              style={{
                flexDirection: 'row',
                justifyContent: 'space-between',
                alignItems: 'center'
              }}
            >
              <Text style={styles.travelSeriesTitle}>Attachments</Text>
              <TouchableOpacity
                style={{
                  flexDirection: 'row',
                  backgroundColor: Colors.ORANGE,
                  gap: 6,
                  alignItems: 'center',
                  justifyContent: 'center',
                  paddingVertical: 7,
                  paddingHorizontal: 12,
                  borderRadius: 20
                }}
              >
                <Text style={{ fontSize: getFontSize(13), fontWeight: '700', color: Colors.WHITE }}>
                  Add
                </Text>
                <FileIcon fill={Colors.WHITE} height={18} />
              </TouchableOpacity>
            </View>
            <FlatList
              data={isExpanded ? testData : testData.slice(0, 8)}
              renderItem={renderItem}
              style={{ flex: 1 }}
              keyExtractor={(item) => item.id.toString()}
              numColumns={4}
              columnWrapperStyle={{
                justifyContent: 'flex-start',
                gap: 12
              }}
              contentContainerStyle={{
                gap: 8,
                alignSelf: 'center'
              }}
              showsVerticalScrollIndicator={false}
              scrollEnabled={false}
            />
          </View>

          <View style={{ gap: 16 }}>
            <View
              style={{
                flexDirection: 'row',
                justifyContent: 'space-between',
                alignItems: 'center'
              }}
            >
              <Text style={styles.travelSeriesTitle}>Photos</Text>
              <TouchableOpacity
                style={{
                  flexDirection: 'row',
                  backgroundColor: Colors.ORANGE,
                  gap: 6,
                  alignItems: 'center',
                  justifyContent: 'center',
                  paddingVertical: 7,
                  paddingHorizontal: 12,
                  borderRadius: 20
                }}
              >
                <Text style={{ fontSize: getFontSize(13), fontWeight: '700', color: Colors.WHITE }}>
                  Add
                </Text>
                <ImageIcon fill={Colors.WHITE} width={18} />
              </TouchableOpacity>
            </View>
          </View>
        </View>
      </ScrollView>
    </View>
  );
};

export default EventScreen;
